@@ -21,8 +21,8 @@ module Whenever
         File.read(options[:file])
       end
 
-      instance_eval(Whenever::NumericSeconds.process_string(setup), setup_file)
-      instance_eval(Whenever::NumericSeconds.process_string(schedule), options[:file] || '<eval>')
+      instance_eval(setup, setup_file)
+      instance_eval(schedule, options[:file] || '<eval>')
     end
 
     def set(variable, value)
@@ -30,10 +30,17 @@ module Whenever
       return if @pre_set_variables[variable]
 
       instance_variable_set("@#{variable}".to_sym, value)
-      self.class.send(:attr_reader, variable.to_sym)
       @set_variables[variable] = value
     end
 
+    def method_missing(name, *args, &block)
+      @set_variables.has_key?(name) ? @set_variables[name] : super
+    end
+
+    def self.respond_to?(name, include_private = false)
+      @set_variables.has_key?(name) || super
+    end
+
     def env(variable, value)
       @env[variable.to_s] = value
     end
@@ -45,18 +52,21 @@ module Whenever
     end
 
     def job_type(name, template)
-      singleton_class_shim.class_eval do
+      singleton_class.class_eval do
         define_method(name) do |task, *args|
           options = { :task => task, :template => template }
           options.merge!(args[0]) if args[0].is_a? Hash
 
+          options[:mailto] ||= @options.fetch(:mailto, :default_mailto)
+
           # :cron_log was an old option for output redirection, it remains for backwards compatibility
           options[:output] = (options[:cron_log] || @cron_log) if defined?(@cron_log) || options.has_key?(:cron_log)
           # :output is the newer, more flexible option.
           options[:output] = @output if defined?(@output) && !options.has_key?(:output)
 
-          @jobs[@current_time_scope] ||= []
-          @jobs[@current_time_scope] << Whenever::Job.new(@options.merge(@set_variables).merge(options))
+          @jobs[options.fetch(:mailto)] ||= {}
+          @jobs[options.fetch(:mailto)][@current_time_scope] ||= []
+          @jobs[options.fetch(:mailto)][@current_time_scope] << Whenever::Job.new(@options.merge(@set_variables).merge(options))
         end
       end
     end
@@ -67,17 +77,6 @@ module Whenever
 
   private
 
-    # The Object#singleton_class method only became available in MRI 1.9.2, so
-    # we need this to maintain 1.8 compatibility. Once 1.8 support is dropped,
-    # this can be removed
-    def singleton_class_shim
-      if self.respond_to?(:singleton_class)
-        singleton_class
-      else
-        class << self; self; end
-      end
-    end
-
     #
     # Takes a string like: "variable1=something&variable2=somethingelse"
     # and breaks it into variable/value pairs. Used for setting variables at runtime from the command line.
@@ -136,31 +135,51 @@ module Whenever
       entries.map { |entry| entry.join(' ') }
     end
 
-    def cron_jobs
-      return if @jobs.empty?
+    def cron_jobs_of_time(time, jobs)
+      shortcut_jobs, regular_jobs = [], []
 
-      shortcut_jobs = []
-      regular_jobs = []
+      jobs.each do |job|
+        next unless roles.empty? || roles.any? do |r|
+          job.has_role?(r)
+        end
+        Whenever::Output::Cron.output(time, job, :chronic_options => @chronic_options) do |cron|
+          cron << "\n\n"
 
-      output_all = roles.empty?
-      @jobs.each do |time, jobs|
-        jobs.each do |job|
-          next unless output_all || roles.any? do |r|
-            job.has_role?(r)
-          end
-          Whenever::Output::Cron.output(time, job) do |cron|
-            cron << "\n\n"
-
-            if cron[0,1] == "@"
-              shortcut_jobs << cron
-            else
-              regular_jobs << cron
-            end
+          if cron[0,1] == "@"
+            shortcut_jobs << cron
+          else
+            regular_jobs << cron
           end
         end
       end
 
       shortcut_jobs.join + combine(regular_jobs).join
     end
+
+    def cron_jobs
+      return if @jobs.empty?
+
+      output = []
+
+      # jobs with default mailto's must be output before the ones with non-default mailto's.
+      @jobs.delete(:default_mailto) { Hash.new }.each do |time, jobs|
+        output << cron_jobs_of_time(time, jobs)
+      end
+
+      @jobs.each do |mailto, time_and_jobs|
+        output_jobs = []
+
+        time_and_jobs.each do |time, jobs|
+          output_jobs << cron_jobs_of_time(time, jobs)
+        end
+
+        output_jobs.reject! { |output_job| output_job.empty? }
+
+        output << "MAILTO=#{mailto}\n\n" unless output_jobs.empty?
+        output << output_jobs
+      end
+
+      output.join
+    end
   end
 end
