@@ -5,6 +5,10 @@ set :environment, "production"
 # Path defaults to the directory `whenever` was run from
 set :path, Whenever.path
 
+# Custom Chronic configuration for time parsing, empty by default
+# Full list of options at: https://github.com/mojombo/chronic/blob/master/lib/chronic/parser.rb
+set :chronic_options, {}
+
 # All jobs are wrapped in this template.
 # http://blog.scoutapp.com/articles/2010/09/07/rvm-and-cron-in-production
 set :job_template, "/bin/bash -l -c ':job'"
@@ -23,4 +27,4 @@ set :bundle_command, Whenever.bundler? ? "bundle exec" : ""
 job_type :command, ":task :output"
 job_type :rake,    "cd :path && :environment_variable=:environment :bundle_command rake :task --silent :output"
 job_type :script,  "cd :path && :environment_variable=:environment :bundle_command script/:task :output"
-job_type :runner,  "cd :path && :runner_command -e :environment ':task' :output"
+job_type :runner,  "cd :path && :bundle_command :runner_command -e :environment ':task' :output"
