@@ -2,7 +2,8 @@ require 'test_helper'
 
 class CommandLineWriteTest < Whenever::TestCase
   setup do
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    Time.stubs(:now).returns(Time.new(2017, 2, 24, 16, 21, 30, '+01:00'))
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
     @command = Whenever::CommandLine.new(:write => true, :identifier => 'My identifier')
     @task = "#{two_hours} /my/command"
     Whenever.expects(:cron).returns(@task)
@@ -10,9 +11,9 @@ class CommandLineWriteTest < Whenever::TestCase
 
   should "output the cron job with identifier blocks" do
     output = <<-EXPECTED
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 #{@task}
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 EXPECTED
 
     assert_equal output, @command.send(:whenever_cron)
@@ -26,7 +27,8 @@ end
 
 class CommandLineUpdateTest < Whenever::TestCase
   setup do
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    Time.stubs(:now).returns(Time.new(2017, 2, 24, 16, 21, 30, '+01:00'))
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
     @command = Whenever::CommandLine.new(:update => true, :identifier => 'My identifier')
     @task = "#{two_hours} /my/command"
     Whenever.expects(:cron).returns(@task)
@@ -39,9 +41,9 @@ class CommandLineUpdateTest < Whenever::TestCase
     new_cron = <<-EXPECTED
 #{existing}
 
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 #{@task}
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 EXPECTED
 
     assert_equal new_cron, @command.send(:updated_crontab)
@@ -50,7 +52,71 @@ EXPECTED
     assert @command.run
   end
 
-  should "replace an existing block if the identifier matches" do
+  should "replace an existing block if the identifier matches and the timestamp doesn't" do
+    existing = <<-EXISTING_CRON
+# Something
+
+# Begin Whenever generated tasks for: My identifier at: 2017-01-03 08:02:22 +0500
+My whenever job that was already here
+# End Whenever generated tasks for: My identifier at: 2017-01-03 08:22:22 +0500
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+EXISTING_CRON
+
+    new_cron = <<-NEW_CRON
+# Something
+
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
+#{@task}
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+NEW_CRON
+
+    @command.expects(:read_crontab).at_least_once.returns(existing)
+    assert_equal new_cron, @command.send(:updated_crontab)
+
+    @command.expects(:write_crontab).with(new_cron).returns(true)
+    assert @command.run
+  end
+
+  should "replace an existing block if the identifier matches and the UTC timestamp doesn't" do
+    existing = <<-EXISTING_CRON
+# Something
+
+# Begin Whenever generated tasks for: My identifier at: 2017-01-03 08:02:22 UTC
+My whenever job that was already here
+# End Whenever generated tasks for: My identifier at: 2017-01-03 08:22:22 UTC
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+EXISTING_CRON
+
+    new_cron = <<-NEW_CRON
+# Something
+
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
+#{@task}
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+NEW_CRON
+
+    @command.expects(:read_crontab).at_least_once.returns(existing)
+    assert_equal new_cron, @command.send(:updated_crontab)
+
+    @command.expects(:write_crontab).with(new_cron).returns(true)
+    assert @command.run
+  end
+
+  should "replace an existing block if the identifier matches and it doesn't contain a timestamp" do
     existing = <<-EXISTING_CRON
 # Something
 
@@ -58,21 +124,21 @@ EXPECTED
 My whenever job that was already here
 # End Whenever generated tasks for: My identifier
 
-# Begin Whenever generated tasks for: Other identifier
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 This shouldn't get replaced
-# End Whenever generated tasks for: Other identifier
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 EXISTING_CRON
 
     new_cron = <<-NEW_CRON
 # Something
 
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 #{@task}
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 
-# Begin Whenever generated tasks for: Other identifier
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 This shouldn't get replaced
-# End Whenever generated tasks for: Other identifier
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 NEW_CRON
 
     @command.expects(:read_crontab).at_least_once.returns(existing)
@@ -85,12 +151,13 @@ end
 
 class CommandLineUpdateWithBackslashesTest < Whenever::TestCase
   setup do
+    Time.stubs(:now).returns(Time.new(2017, 2, 24, 16, 21, 30, '+01:00'))
     @existing = <<-EXISTING_CRON
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 script/runner -e production 'puts '\\''hello'\\'''
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 EXISTING_CRON
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
     @command = Whenever::CommandLine.new(:update => true, :identifier => 'My identifier')
     @command.expects(:read_crontab).at_least_once.returns(@existing)
     @command.expects(:whenever_cron).returns(@existing)
@@ -104,14 +171,14 @@ end
 class CommandLineUpdateToSimilarCrontabTest < Whenever::TestCase
   setup do
     @existing = <<-EXISTING_CRON
-# Begin Whenever generated tasks for: WheneverExisting
-# End Whenever generated tasks for: WheneverExisting
+# Begin Whenever generated tasks for: WheneverExisting at: 2017-02-24 16:21:30 +0100
+# End Whenever generated tasks for: WheneverExisting at: 2017-02-24 16:21:30 +0100
 EXISTING_CRON
     @new = <<-NEW_CRON
-# Begin Whenever generated tasks for: Whenever
-# End Whenever generated tasks for: Whenever
+# Begin Whenever generated tasks for: Whenever at: 2017-02-24 16:21:30 +0100
+# End Whenever generated tasks for: Whenever at: 2017-02-24 16:21:30 +0100
 NEW_CRON
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
     @command = Whenever::CommandLine.new(:update => true, :identifier => 'Whenever')
     @command.expects(:read_crontab).at_least_once.returns(@existing)
     @command.expects(:whenever_cron).returns(@new)
@@ -124,22 +191,23 @@ end
 
 class CommandLineClearTest < Whenever::TestCase
   setup do
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    Time.stubs(:now).returns(Time.new(2017, 2, 24, 16, 21, 30, '+01:00'))
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
     @command = Whenever::CommandLine.new(:clear => true, :identifier => 'My identifier')
     @task = "#{two_hours} /my/command"
   end
 
-  should "clear an existing block if the identifier matches" do
+  should "clear an existing block if the identifier matches and the timestamp doesn't" do
     existing = <<-EXISTING_CRON
 # Something
 
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-01-03 08:20:02 +0500
 My whenever job that was already here
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-01-03 08:20:02 +0500
 
-# Begin Whenever generated tasks for: Other identifier
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 This shouldn't get replaced
-# End Whenever generated tasks for: Other identifier
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 EXISTING_CRON
 
     @command.expects(:read_crontab).at_least_once.returns(existing)
@@ -147,9 +215,67 @@ EXISTING_CRON
     new_cron = <<-NEW_CRON
 # Something
 
-# Begin Whenever generated tasks for: Other identifier
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 This shouldn't get replaced
-# End Whenever generated tasks for: Other identifier
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+NEW_CRON
+
+    assert_equal new_cron, @command.send(:updated_crontab)
+
+    @command.expects(:write_crontab).with(new_cron).returns(true)
+    assert @command.run
+  end
+
+  should "clear an existing block if the identifier matches and the UTC timestamp doesn't" do
+    existing = <<-EXISTING_CRON
+# Something
+
+# Begin Whenever generated tasks for: My identifier at: 2017-01-03 08:20:02 UTC
+My whenever job that was already here
+# End Whenever generated tasks for: My identifier at: 2017-01-03 08:20:02 UTC
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+EXISTING_CRON
+
+    @command.expects(:read_crontab).at_least_once.returns(existing)
+
+    new_cron = <<-NEW_CRON
+# Something
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+NEW_CRON
+
+    assert_equal new_cron, @command.send(:updated_crontab)
+
+    @command.expects(:write_crontab).with(new_cron).returns(true)
+    assert @command.run
+  end
+
+  should "clear an existing block if the identifier matches and it doesn't have a timestamp" do
+    existing = <<-EXISTING_CRON
+# Something
+
+# Begin Whenever generated tasks for: My identifier
+My whenever job that was already here
+# End Whenever generated tasks for: My identifier
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+EXISTING_CRON
+
+    @command.expects(:read_crontab).at_least_once.returns(existing)
+
+    new_cron = <<-NEW_CRON
+# Something
+
+# Begin Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
+This shouldn't get replaced
+# End Whenever generated tasks for: Other identifier at: 2017-02-24 16:21:30 +0100
 NEW_CRON
 
     assert_equal new_cron, @command.send(:updated_crontab)
@@ -161,7 +287,7 @@ end
 
 class CommandLineClearWithNoScheduleTest < Whenever::TestCase
   setup do
-    File.expects(:exists?).with('config/schedule.rb').returns(false)
+    File.expects(:exist?).with('config/schedule.rb').returns(false)
     @command = Whenever::CommandLine.new(:clear => true, :identifier => 'My identifier')
   end
 
@@ -173,13 +299,14 @@ end
 
 class CommandLineUpdateWithNoIdentifierTest < Whenever::TestCase
   setup do
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    Time.stubs(:now).returns(Time.new(2017, 2, 24, 16, 21, 30, '+01:00'))
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
     Whenever::CommandLine.any_instance.expects(:default_identifier).returns('DEFAULT')
-    @command = Whenever::CommandLine.new(:update => true, :file => @file)
+    @command = Whenever::CommandLine.new(:update => true)
   end
 
   should "use the default identifier" do
-    assert_equal "Whenever generated tasks for: DEFAULT", @command.send(:comment_base)
+    assert_equal "Whenever generated tasks for: DEFAULT at: 2017-02-24 16:21:30 +0100", @command.send(:comment_base)
   end
 end
 
@@ -187,7 +314,7 @@ class CombinedParamsTest < Whenever::TestCase
   setup do
     Whenever::CommandLine.any_instance.expects(:exit)
     Whenever::CommandLine.any_instance.expects(:warn)
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
   end
 
   should "exit with write and clear" do
@@ -217,7 +344,7 @@ class RunnerOverwrittenWithSetOptionTest < Whenever::TestCase
   end
 
   should "output the runner using the override environment" do
-    assert_match two_hours + %( cd /my/path && script/runner -e serious 'blahblah'), @output
+    assert_match two_hours + %( cd /my/path && bundle exec script/runner -e serious 'blahblah'), @output
   end
 end
 
@@ -236,7 +363,7 @@ class EnvironmentAndPathOverwrittenWithSetOptionTest < Whenever::TestCase
   end
 
   should "output the runner using the overridden path and environment" do
-    assert_match two_hours + %( cd /serious/path && script/runner -e serious 'blahblah'), @output
+    assert_match two_hours + %( cd /serious/path && bundle exec script/runner -e serious 'blahblah'), @output
   end
 end
 
@@ -254,7 +381,7 @@ class EnvironmentAndPathOverwrittenWithSetOptionWithSpacesTest < Whenever::TestC
   end
 
   should "output the runner using the overridden path and environment" do
-    assert_match two_hours + %( cd /serious/path && script/runner -e serious 'blahblah'), @output
+    assert_match two_hours + %( cd /serious/path && bundle exec script/runner -e serious 'blahblah'), @output
   end
 end
 
@@ -272,13 +399,13 @@ class EnvironmentOverwrittenWithoutValueTest < Whenever::TestCase
   end
 
   should "output the runner using the original environmnet" do
-    assert_match two_hours + %( cd /silly/path && script/runner -e silly 'blahblah'), @output
+    assert_match two_hours + %( cd /silly/path && bundle exec script/runner -e silly 'blahblah'), @output
   end
 end
 
 class PreparingOutputTest < Whenever::TestCase
   setup do
-    File.expects(:exists?).with('config/schedule.rb').returns(true)
+    File.expects(:exist?).with('config/schedule.rb').returns(true)
   end
 
   should "not trim off the top lines of the file" do
@@ -287,9 +414,9 @@ class PreparingOutputTest < Whenever::TestCase
 # Useless Comments
 # at the top of the file
 
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 My whenever job that was already here
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 EXISTING_CRON
 
     assert_equal existing, @command.send(:prepare, existing)
@@ -301,15 +428,15 @@ EXISTING_CRON
 # Useless Comments
 # at the top of the file
 
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 My whenever job that was already here
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 EXISTING_CRON
 
     new_cron = <<-NEW_CRON
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 My whenever job that was already here
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 NEW_CRON
 
     assert_equal new_cron, @command.send(:prepare, existing)
@@ -318,9 +445,9 @@ NEW_CRON
   should "preserve terminating newlines in files" do
     @command = Whenever::CommandLine.new(:update => true, :identifier => 'My identifier')
     existing = <<-EXISTING_CRON
-# Begin Whenever generated tasks for: My identifier
+# Begin Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 My whenever job that was already here
-# End Whenever generated tasks for: My identifier
+# End Whenever generated tasks for: My identifier at: 2017-02-24 16:21:30 +0100
 
 # A non-Whenever task
 My non-whenever job that was already here
