@@ -69,11 +69,11 @@ class OutputAtTest < Whenever::TestCase
       set :job_template, nil
       set :path, '/your/path'
       every "mon,wed,fri", :at => '5:02am, 3:02pm' do
-        runner "blahblah"
+        runner "Worker.perform_async(1.day.ago)"
       end
     file
 
-    assert_match %(2 5,15 * * 1,3,5 cd /your/path && script/runner -e production 'blahblah'), output
+    assert_match %(2 5,15 * * 1,3,5 cd /your/path && bundle exec script/runner -e production 'Worker.perform_async(1.day.ago)'), output
   end
 
   test "various days at a various aligned times using a rake task" do
@@ -138,9 +138,9 @@ class OutputAtTest < Whenever::TestCase
     file
 
     assert_match '@daily cd /your/path && RAILS_ENV=production bundle exec rake blah:blah --silent', output
-    assert_match %(@daily cd /your/path && script/runner -e production 'runner_1'), output
+    assert_match %(@daily cd /your/path && bundle exec script/runner -e production 'runner_1'), output
     assert_match '@daily command_1', output
-    assert_match %(@daily cd /your/path && script/runner -e production 'runner_2'), output
+    assert_match %(@daily cd /your/path && bundle exec script/runner -e production 'runner_2'), output
     assert_match '@daily command_2', output
   end
 
@@ -204,4 +204,43 @@ class OutputAtTest < Whenever::TestCase
 
     assert_match '0 0 27,31 * * blahblah', output
   end
+
+  test "using custom Chronic configuration to specify time using 24 hour clock" do
+    output = Whenever.cron \
+    <<-file
+      set :job_template, nil
+      set :chronic_options, :hours24 => true
+      every 1.day, :at => '03:00' do
+        command "blahblah"
+      end
+    file
+
+    assert_match '0 3 * * * blahblah', output
+  end
+
+  test "using custom Chronic configuration to specify date using little endian preference" do
+    output = Whenever.cron \
+    <<-file
+      set :job_template, nil
+      set :chronic_options, :endian_precedence => :little
+      every 1.month, :at => '02/03 10:15' do
+        command "blahblah"
+      end
+    file
+
+    assert_match '15 10 2 * * blahblah', output
+  end
+
+  test "using custom Chronic configuration to specify time using 24 hour clock and date using little endian preference" do
+    output = Whenever.cron \
+    <<-file
+      set :job_template, nil
+      set :chronic_options, :hours24 => true, :endian_precedence => :little
+      every 1.month, :at => '01/02 04:30' do
+        command "blahblah"
+      end
+    file
+
+    assert_match '30 4 1 * * blahblah', output
+  end
 end
