@@ -13,7 +13,7 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
       end
     file
 
-    assert_match /^.+ .+ .+ .+ blahblah$/, output
+    assert_match(/^.+ .+ .+ .+ blahblah$/, output)
   end
 
   test "A plain command with no job template set" do
@@ -24,7 +24,7 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
       end
     file
 
-    assert_match /^.+ .+ .+ .+ \/bin\/bash -l -c 'blahblah'$/, output
+    assert_match(/^.+ .+ .+ .+ \/bin\/bash -l -c 'blahblah'$/, output)
   end
 
   test "A plain command with a job_template using a normal parameter" do
@@ -37,7 +37,7 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
       end
     file
 
-    assert_match /^.+ .+ .+ .+ \/bin\/bash -l -c 'cd \/tmp \&\& blahblah'$/, output
+    assert_match(/^.+ .+ .+ .+ \/bin\/bash -l -c 'cd \/tmp \&\& blahblah'$/, output)
   end
 
   test "A plain command that overrides the job_template set" do
@@ -50,8 +50,8 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
     file
 
 
-    assert_match /^.+ .+ .+ .+ \/bin\/sh -l -c 'blahblah'$/, output
-    assert_no_match /bash/, output
+    assert_match(/^.+ .+ .+ .+ \/bin\/sh -l -c 'blahblah'$/, output)
+    assert_no_match(/bash/, output)
   end
 
   test "A plain command that overrides the job_template set using a parameter" do
@@ -65,8 +65,8 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
     file
 
 
-    assert_match /^.+ .+ .+ .+ \/bin\/sh -l -c 'cd \/tmp && blahblah'$/, output
-    assert_no_match /bash/, output
+    assert_match(/^.+ .+ .+ .+ \/bin\/sh -l -c 'cd \/tmp && blahblah'$/, output)
+    assert_no_match(/bash/, output)
   end
 
   test "A plain command that is conditional on default environent and path" do
@@ -81,7 +81,7 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
       end
     file
 
-    assert_match /blahblah/, output
+    assert_match(/blahblah/, output)
   end
 
   # runner
@@ -96,7 +96,7 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
       end
     file
 
-    assert_match two_hours + %( cd /my/path && script/runner -e production 'blahblah'), output
+    assert_match two_hours + %( cd /my/path && bundle exec script/runner -e production 'blahblah'), output
   end
 
   test "A runner that overrides the path set" do
@@ -109,7 +109,21 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
       end
     file
 
-    assert_match two_hours + %( cd /some/other/path && script/runner -e production 'blahblah'), output
+    assert_match two_hours + %( cd /some/other/path && bundle exec script/runner -e production 'blahblah'), output
+  end
+
+  test "A runner for a non-bundler app" do
+    Whenever.expects(:bundler?).returns(false)
+    output = Whenever.cron \
+    <<-file
+      set :job_template, nil
+      set :path, '/my/path'
+      every 2.hours do
+        runner 'blahblah'
+      end
+    file
+
+    assert_match two_hours + %( cd /my/path && script/runner -e production 'blahblah'), output
   end
 
   test "A runner for an app with bin/rails" do
@@ -155,6 +169,19 @@ class OutputDefaultDefinedJobsTest < Whenever::TestCase
     assert_match two_hours + ' cd /my/path && RAILS_ENV=production bundle exec rake blahblah --silent', output
   end
 
+  test "A rake command with arguments" do
+    output = Whenever.cron \
+    <<-file
+      set :job_template, nil
+      set :path, '/my/path'
+      every 2.hours do
+        rake "blahblah[foobar]"
+      end
+    file
+
+    assert_match two_hours + ' cd /my/path && RAILS_ENV=production bundle exec rake blahblah[foobar] --silent', output
+  end
+
   test "A rake for a non-bundler app" do
     Whenever.expects(:path).at_least_once.returns('/my/path')
     Whenever.expects(:bundler?).returns(false)
